|License| |Build Status|

Introduction
============

This project provides a Python 2.7/3.x library for common tasks
especially when writing shell-like scripts. Some of the functionality
overlaps with the standard library but the API is slightly modified.

Status
======

The status of this project is **pre-alpha**. This project is not yet
suitable for use other than testing.

Requirements
============

Auxly should run on any Python 2.7/3.x interpreter without additional
dependencies.

Usage
=====

The following are basic examples of Auxly (all examples can be found
`here <https://github.com/jeffrimko/Auxly/tree/master/examples>`__):

-  `examples/delete\_1.py <https://github.com/jeffrimko/Auxly/blob/master/examples/delete_1.py>`__
   - Deletes all PYC files in the project.

.. |License| image:: http://img.shields.io/:license-mit-blue.svg
.. |Build Status| image:: https://travis-ci.org/jeffrimko/Auxly.svg?branch=master
